Set the width of items for common large `item+label` widgets.

- `>0`: width in pixels
- `<0`: align `x` pixels to the right of window (so -1 always align width to the right side)
- `=0`: default to ~2/3 of the window width

See [ImGuiPopItemWidth].